from fastapi import FastAPI
from models import Operandos
from operations import soma, subtracao, multiplicacao, divisao, potencia, raiz

app = FastAPI()

@app.post("/soma")
def somaRoute(operando: Operandos):
    return soma(operando)

@app.post("/subtracao")
def subtracaoRoute(operando: Operandos):
    return subtracao(operando)

@app.post("/multiplicacao")
def multiplicacaoRoute(operando: Operandos):
    return multiplicacao(operando)

@app.post("/divisao")
def divisaoRoute(operando: Operandos):
    return divisao(operando)

@app.post("/potencia")
def potenciaRoute(operando: Operandos):
    return potencia(operando)

@app.post("/raiz")
def raizRoute(operando: Operandos):
    return raiz(operando)



def soma(operando: Operandos):
    return {"resultado": operando.num1 + operando.num2}

def subtracao(operando: Operandos):
    return {"resultado": operando.num1 - operando.num2}

def multiplicacao(operando: Operandos):
    return {"resultado": operando.num1 * operando.num2}

def divisao(operando: Operandos):
    if operando.num2 == 0:
        return {"erro": "Divisão por zero não é permitida."}
    return {"resultado": operando.num1 / operando.num2}

def potencia(operando: Operandos):
    return {"resultado": operando.num1 ** operando.num2}

def raiz(operando: Operandos):
    if operando.num1 < 0:
        return {"erro": "Raiz quadrada de número negativo não é permitida."}
    return {"resultado": operando.num1 ** (1 / operando.num2)}


from setuptools import setup, find_packages

setup(
    name="calculadoraapi-fastapi-breno",
    version="0.1.4",
    description="Calculadora API utilizando FastAPI",
    author="Breno Amâncio",
    license="MIT",
    packages=find_packages(),
    install_requires=[
        "fastapi>=0.95.2,<0.100.0",  # Compatível com Pydantic v1
        "pydantic==1.10.7",
        "uvicorn==0.22.0"
    ],
    include_package_data=True,
    python_requires=">=3.9, <=3.12.5"
)